pub struct Host {
pub name: String,
pub base: Option<String>,
pub enabled: bool,
}Expand description
One host opened without being asked for, and where it is rooted.
Fields
name: Stringbase: Option<String>None for the remote’s home directory, resolved when it is first connected.
enabled: boolTrait Implementations
impl Eq for Host
impl StructuralPartialEq for Host